# https://github.com/mozillazg/python-pinyin/blob/5fd340381138f61e10d978a877e7954f1940d292/pypinyin/phonetic_symbol.py#L7
PHONETIC_SYMBOLS = {
    "ā": "a",
    "á": "a",
    "ǎ": "a",
    "à": "a",
    "ē": "e",
    "é": "e",
    "ě": "e",
    "è": "e",
    "ō": "o",
    "ó": "o",
    "ǒ": "o",
    "ò": "o",
    "ī": "i",
    "í": "i",
    "ǐ": "i",
    "ì": "i",
    "ū": "u",
    "ú": "u",
    "ǔ": "u",
    "ù": "u",
    "ü": "v",
    "ǖ": "v",
    "ǘ": "v",
    "ǚ": "v",
    "ǜ": "v",
    "ń": "n",
    "ň": "n",
    "ǹ": "n",
    "m̄": "m",
    "ḿ": "m",
    "m̀": "m",
    "ê̄": "e",
    "ế": "e",
    "ê̌": "e",
    "ề": "e",
}

PINYIN_TO_KATAKANA = {
    "a": "ア",
    "ā": "アー",
    "á": "アー",
    "ǎ": "アー",
    "à": "アー",
    "ai": "アイ",
    "an": "アン",
    "ān": "アーン",
    "án": "アーン",
    "ǎn": "アーン",
    "àn": "アーン",
    "ang": "アン",
    "āng": "アーン",
    "áng": "アーン",
    "ǎng": "アーン",
    "àng": "アーン",
    "ao": "アオ",
    "āo": "アーオ",
    "áo": "アーオ",
    "ǎo": "アーオ",
    "ào": "アーオ",
    "ba": "バ",
    "bā": "バー",
    "bá": "バー",
    "bǎ": "バー",
    "bà": "バー",
    "bai": "バイ",
    "bāi": "バーイ",
    "bái": "バーイ",
    "bǎi": "バーイ",
    "bài": "バーイ",
    "ban": "バン",
    "bān": "バーン",
    "bán": "バーン",
    "bǎn": "バーン",
    "bàn": "バーン",
    "bang": "バン",
    "bāng": "バーン",
    "báng": "バーン",
    "bǎng": "バーン",
    "bàng": "バーン",
    "bao": "バオ",
    "bāo": "バーオ",
    "báo": "バーオ",
    "bǎo": "バーオ",
    "bào": "バーオ",
    "bei": "ベイ",
    "bēi": "ベーイ",
    "béi": "ベーイ",
    "běi": "ベーイ",
    "bèi": "ベーイ",
    "ben": "ベン",
    "bēn": "ベーン",
    "bén": "ベーン",
    "běn": "ベーン",
    "bèn": "ベーン",
    "beng": "ベン",
    "bēng": "ベーン",
    "béng": "ベーン",
    "běng": "ベーン",
    "bèng": "ベーン",
    "bi": "ビ",
    "bī": "ビー",
    "bí": "ビー",
    "bǐ": "ビー",
    "bì": "ビー",
    "bian": "ビェン",
    "biān": "ビェーン",
    "bián": "ビェーン",
    "biǎn": "ビェーン",
    "biàn": "ビェーン",
    "biao": "ビャオ",
    "biāo": "ビャーオ",
    "biáo": "ビャーオ",
    "biǎo": "ビャーオ",
    "biào": "ビャーオ",
    "bie": "ビェ",
    "biē": "ビェー",
    "bié": "ビェー",
    "biě": "ビェー",
    "biè": "ビェー",
    "bin": "ビン",
    "bīn": "ビーン",
    "bing": "ビン",
    "bīng": "ビーン",
    "bing": "ビン",
    "bo": "ボ",
    "bō": "ボー",
    "bó": "ボー",
    "bǒ": "ボー",
    "bò": "ボー",
    "bu": "ブ",
    "bū": "ブー",
    "bú": "ブー",
    "bǔ": "ブー",
    "bù": "ブー",
    "ca": "ツァ",
    "cā": "ツァー",
    "cá": "ツァー",
    "cǎ": "ツァー",
    "cà": "ツァー",
    "cai": "ツァイ",
    "cāi": "ツァーイ",
    "cái": "ツァーイ",
    "cǎi": "ツァーイ",
    "cài": "ツァーイ",
    "can": "ツァン",
    "cān": "ツァーン",
    "cán": "ツァーン",
    "cǎn": "ツァーン",
    "càn": "ツァーン",
    "cang": "ツァン",
    "cāng": "ツァーン",
    "cáng": "ツァーン",
    "cǎng": "ツァーン",
    "càng": "ツァーン",
    "cao": "ツァオ",
    "cāo": "ツァーオ",
    "cáo": "ツァーオ",
    "cǎo": "ツァーオ",
    "cào": "ツァーオ",
    "ce": "ツェ",
    "cē": "ツェー",
    "cé": "ツェー",
    "cě": "ツェー",
    "cè": "ツェー",
    "cen": "ツェン",
    "cēn": "ツェーン",
    "cén": "ツェーン",
    "cěn": "ツェーン",
    "cèn": "ツェーン",
    "ceng": "ツォン",
    "cēng": "ツォーン",
    "céng": "ツォーン",
    "cěng": "ツォーン",
    "cèng": "ツォーン",
    "cha": "チャ",
    "chā": "チャー",
    "chá": "チャー",
    "chǎ": "チャー",
    "chà": "チャー",
    "chai": "チャイ",
    "chāi": "チャーイ",
    "chái": "チャーイ",
    "chǎi": "チャーイ",
    "chài": "チャーイ",
    "chan": "チャン",
    "chān": "チャーン",
    "chán": "チャーン",
    "chǎn": "チャーン",
    "chàn": "チャーン",
    "chang": "チャン",
    "chāng": "チャーン",
    "cháng": "チャーン",
    "chǎng": "チャーン",
    "chàng": "チャーン",
    "chao": "チャオ",
    "chāo": "チャーオ",
    "cháo": "チャーオ",
    "chǎo": "チャーオ",
    "chào": "チャーオ",
    "che": "チェ",
    "chē": "チェー",
    "ché": "チェー",
    "chě": "チェー",
    "chè": "チェー",
    "chen": "チェン",
    "chēn": "チェーン",
    "chén": "チェーン",
    "chěn": "チェーン",
    "chèn": "チェーン",
    "cheng": "チェン",
    "chēng": "チェーン",
    "chéng": "チェーン",
    "chěng": "チェーン",
    "chèng": "チェーン",
    "chi": "チ",
    "chī": "チー",
    "chí": "チー",
    "chǐ": "チー",
    "chì": "チー",
    "chong": "チョン",
    "chōng": "チョーン",
    "chóng": "チョーン",
    "chǒng": "チョーン",
    "chòng": "チョーン",
    "chou": "チョウ",
    "chōu": "チョーウ",
    "chóu": "チョーウ",
    "chǒu": "チョーウ",
    "chòu": "チョーウ",
    "chu": "チュ",
    "chū": "チュー",
    "chú": "チュー",
    "chǔ": "チュー",
    "chù": "チュー",
    "chua": "チュア",
    "chuā": "チュアー",
    "chuá": "チュアー",
    "chuǎ": "チュアー",
    "chuà": "チュアー",
    "chuai": "チュアイ",
    "chuāi": "チュアーイ",
    "chuái": "チュアーイ",
    "chuǎi": "チュアーイ",
    "chuài": "チュアーイ",
    "chuan": "チュアン",
    "chuān": "チュアーン",
    "chuán": "チュアーン",
    "chuǎn": "チュアーン",
    "chuàn": "チュアーン",
    "chuang": "チュアン",
    "chuāng": "チュアーン",
    "chuáng": "チュアーン",
    "chuǎng": "チュアーン",
    "chuàng": "チュアーン",
    "chui": "チュェイ",
    "chuī": "チュェーイ",
    "chuí": "チュェーイ",
    "chuǐ": "チュェーイ",
    "chuì": "チュェーイ",
    "chun": "チュン",
    "chūn": "チューン",
    "chún": "チューン",
    "chǔn": "チューン",
    "chùn": "チューン",
    "chuo": "チュォ",
    "chuō": "チュォー",
    "chuó": "チュォー",
    "chuǒ": "チュォー",
    "chuò": "チュォー",
    "ci": "ツ",
    "cī": "ツー",
    "cí": "ツー",
    "cǐ": "ツー",
    "cì": "ツー",
    "cong": "ツォン",
    "cōng": "ツォーン",
    "cóng": "ツォーン",
    "cǒng": "ツォーン",
    "còng": "ツォーン",
    "cou": "ツォウ",
    "cōu": "ツォーウ",
    "cóu": "ツォーウ",
    "cǒu": "ツォーウ",
    "còu": "ツォーウ",
    "cu": "ツ",
    "cū": "ツー",
    "cú": "ツー",
    "cǔ": "ツー",
    "cù": "ツー",
    "cuan": "ツァン",
    "cuān": "ツァーン",
    "cuán": "ツァーン",
    "cuǎn": "ツァーン",
    "cuàn": "ツァーン",
    "cui": "ツェイ",
    "cuī": "ツェーイ",
    "cuí": "ツェーイ",
    "cuǐ": "ツェーイ",
    "cuì": "ツェーイ",
    "cun": "ツン",
    "cūn": "ツーン",
    "cún": "ツーン",
    "cǔn": "ツーン",
    "cùn": "ツーン",
    "cuo": "ツォ",
    "cuō": "ツォー",
    "cuó": "ツォー",
    "cuǒ": "ツォー",
    "cuò": "ツォー",
    "da": "ダ",
    "dā": "ダー",
    "dá": "ダー",
    "dǎ": "ダー",
    "dà": "ダー",
    "dai": "ダイ",
    "dāi": "ダーイ",
    "dái": "ダーイ",
    "dǎi": "ダーイ",
    "dài": "ダーイ",
    "dan": "ダン",
    "dān": "ダーン",
    "dán": "ダーン",
    "dǎn": "ダーン",
    "dàn": "ダーン",
    "dang": "ダン",
    "dāng": "ダーン",
    "dáng": "ダーン",
    "dǎng": "ダーン",
    "dàng": "ダーン",
    "dao": "ダオ",
    "dāo": "ダーオ",
    "dáo": "ダーオ",
    "dǎo": "ダーオ",
    "dào": "ダーオ",
    "de": "デ",
    "dé": "デー",
    "dě": "デー",
    "dè": "デー",
    "dei": "デイ",
    "dēi": "デーイ",
    "déi": "デーイ",
    "děi": "デーイ",
    "dèi": "デーイ",
    "den": "デン",
    "dēn": "デーン",
    "dén": "デーン",
    "děn": "デーン",
    "dèn": "デーン",
    "deng": "デン",
    "dēng": "デーング",
    "déng": "デーング",
    "děng": "デーング",
    "dèng": "デーング",
    "di": "ディ",
    "dī": "ディー",
    "dí": "ディー",
    "dǐ": "ディー",
    "dì": "ディー",
    "dia": "ディア",
    "diā": "ディーア",
    "diá": "ディーア",
    "diǎ": "ディーア",
    "dià": "ディーア",
    "dian": "ディェン",
    "diān": "ディェーン",
    "dián": "ディェーン",
    "diǎn": "ディェーン",
    "diàn": "ディェーン",
    "diao": "ディャオ",
    "diāo": "ディャーオ",
    "diáo": "ディャーオ",
    "diǎo": "ディャーオ",
    "diào": "ディャーオ",
    "die": "ディェ",
    "diē": "ディェー",
    "dié": "ディェー",
    "diě": "ディェー",
    "diè": "ディェー",
    "ding": "ディン",
    "dīng": "ディーン",
    "díng": "ディーン",
    "dǐng": "ディーン",
    "dìng": "ディーン",
    "diu": "ディウ",
    "diū": "ディーウ",
    "dong": "ドン",
    "dōng": "ドーング",
    "dóng": "ドーング",
    "dǒng": "ドーング",
    "dòng": "ドーング",
    "dou": "ドウ",
    "dōu": "ドーウ",
    "dóu": "ドーウ",
    "dǒu": "ドーウ",
    "dòu": "ドーウ",
    "du": "ドゥ",
    "dū": "ドゥー",
    "dú": "ドゥー",
    "dǔ": "ドゥー",
    "dù": "ドゥー",
    "duan": "ドゥアン",
    "duān": "ドゥーアン",
    "duán": "ドゥーアン",
    "duǎn": "ドゥーアン",
    "duàn": "ドゥーアン",
    "dui": "ドゥェイ",
    "duī": "ドゥェーイ",
    "duí": "ドゥェーイ",
    "duǐ": "ドゥェーイ",
    "duì": "ドゥェーイ",
    "dun": "ドゥン",
    "dūn": "ドゥーン",
    "dún": "ドゥーン",
    "dǔn": "ドゥーン",
    "dùn": "ドゥーン",
    "duo": "ドゥォ",
    "duō": "ドゥーオ",
    "duó": "ドゥーオ",
    "duǒ": "ドゥーオ",
    "duò": "ドゥーオ",
    "e": "エ",
    "ē": "エー",
    "é": "エー",
    "ě": "エー",
    "è": "エー",
    "ei": "エイ",
    "ēi": "エーイ",
    "éi": "エーイ",
    "ěi": "エーイ",
    "èi": "エーイ",
    "en": "エン",
    "ēn": "エーン",
    "én": "エーン",
    "eng": "エン",
    "ēng": "エーン",
    "éng": "エーン",
    "er": "アル",
    "ēr": "アール",
    "ér": "アール",
    "fa": "ファ",
    "fā": "ファー",
    "fá": "ファー",
    "fǎ": "ファー",
    "fà": "ファー",
    "fan": "ファン",
    "fān": "ファーン",
    "fán": "ファーン",
    "fǎn": "ファーン",
    "fàn": "ファーン",
    "fang": "ファン",
    "fāng": "ファーン",
    "fáng": "ファーン",
    "fǎng": "ファーン",
    "fàng": "ファーン",
    "fei": "フェイ",
    "fēi": "フェーイ",
    "féi": "フェーイ",
    "fěi": "フェーイ",
    "fèi": "フェーイ",
    "fen": "フェン",
    "fēn": "フェーン",
    "fén": "フェーン",
    "fěn": "フェーン",
    "fèn": "フェーン",
    "feng": "フェン",
    "fēng": "フェーン",
    "féng": "フェーン",
    "fěng": "フェーン",
    "fèng": "フェーン",
    "fo": "フォ",
    "fō": "フォー",
    "fó": "フォー",
    "fǒ": "フォー",
    "fò": "フォー",
    "fou": "フォウ",
    "fōu": "フォーウ",
    "fóu": "フォーウ",
    "fǒu": "フォーウ",
    "fòu": "フォーウ",
    "fu": "フ",
    "fū": "フー",
    "fú": "フー",
    "fǔ": "フー",
    "fù": "フー",
    "ga": "ガ",
    "gā": "ガー",
    "gá": "ガー",
    "gǎ": "ガー",
    "gà": "ガー",
    "gai": "ガイ",
    "gāi": "ガーイ",
    "gái": "ガーイ",
    "gǎi": "ガーイ",
    "gài": "ガーイ",
    "gan": "ガン",
    "gān": "ガーン",
    "gán": "ガーン",
    "gǎn": "ガーン",
    "gàn": "ガーン",
    "gang": "ガン",
    "gāng": "ガーン",
    "gáng": "ガーン",
    "gǎng": "ガーン",
    "gàng": "ガーン",
    "gao": "ガオ",
    "gāo": "ガーオ",
    "gáo": "ガーオ",
    "gǎo": "ガーオ",
    "gào": "ガーオ",
    "ge": "ゲ",
    "gē": "ゲー",
    "gé": "ゲー",
    "gě": "ゲー",
    "gè": "ゲー",
    "gei": "ゲイ",
    "gēi": "ゲーイ",
    "géi": "ゲーイ",
    "gěi": "ゲーイ",
    "gèi": "ゲーイ",
    "gen": "ゲン",
    "gēn": "ゲーン",
    "gén": "ゲーン",
    "gěn": "ゲーン",
    "gèn": "ゲーン",
    "geng": "ゲン",
    "gēng": "ゲーン",
    "géng": "ゲーン",
    "gěng": "ゲーン",
    "gèng": "ゲーン",
    "gong": "ゴン",
    "gōng": "ゴーン",
    "góng": "ゴーン",
    "gǒng": "ゴーン",
    "gòng": "ゴーン",
    "gou": "ゴウ",
    "gōu": "ゴーウ",
    "góu": "ゴーウ",
    "gǒu": "ゴーウ",
    "gòu": "ゴーウ",
    "gu": "グ",
    "gū": "グー",
    "gú": "グー",
    "gǔ": "グー",
    "gù": "グー",
    "gua": "グア",
    "guā": "グーア",
    "guá": "グーア",
    "guǎ": "グーア",
    "guà": "グーア",
    "guai": "グアイ",
    "guāi": "グーアイ",
    "guái": "グーアイ",
    "guǎi": "グーアイ",
    "guài": "グーアイ",
    "guan": "グァン",
    "guān": "グーァン",
    "guán": "グーァン",
    "guǎn": "グーァン",
    "guàn": "グーァン",
    "guang": "グァン",
    "guāng": "グーァン",
    "guáng": "グーァン",
    "guǎng": "グーァン",
    "guàng": "グーァン",
    "gui": "グェイ",
    "guī": "グェーイ",
    "guí": "グェーイ",
    "guǐ": "グェーイ",
    "guì": "グェーイ",
    "gun": "グン",
    "gūn": "グーン",
    "gún": "グーン",
    "gǔn": "グーン",
    "gùn": "グーン",
    "guo": "グォ",
    "guō": "グォー",
    "guó": "グォー",
    "guǒ": "グォー",
    "guò": "グォー",
    "ha": "ハ",
    "hā": "ハー",
    "há": "ハー",
    "hǎ": "ハー",
    "hà": "ハー",
    "hai": "ハイ",
    "hāi": "ハーイ",
    "hái": "ハーイ",
    "hǎi": "ハーイ",
    "hài": "ハーイ",
    "han": "ハン",
    "hān": "ハーン",
    "hán": "ハーン",
    "hǎn": "ハーン",
    "hàn": "ハーン",
    "hang": "ハン",
    "hāng": "ハーン",
    "háng": "ハーン",
    "hǎng": "ハーン",
    "hàng": "ハーン",
    "hao": "ハオ",
    "hāo": "ハーオ",
    "háo": "ハーオ",
    "hǎo": "ハーオ",
    "hào": "ハーオ",
    "he": "ヘ",
    "hē": "ヘー",
    "hé": "ヘー",
    "hě": "ヘー",
    "hè": "ヘー",
    "hei": "ヘイ",
    "hēi": "ヘーイ",
    "héi": "ヘーイ",
    "hěi": "ヘーイ",
    "hèi": "ヘーイ",
    "hen": "ヘン",
    "hēn": "ヘーン",
    "hén": "ヘーン",
    "hěn": "ヘーン",
    "hèn": "ヘーン",
    "heng": "ヘン",
    "hēng": "ヘーン",
    "héng": "ヘーン",
    "hěng": "ヘーン",
    "hèng": "ヘーン",
    "hong": "ホン",
    "hōng": "ホーン",
    "hóng": "ホーン",
    "hǒng": "ホーン",
    "hòng": "ホーン",
    "hou": "ホウ",
    "hōu": "ホーウ",
    "hóu": "ホーウ",
    "hǒu": "ホーウ",
    "hòu": "ホーウ",
    "hu": "フ",
    "hū": "フー",
    "hú": "フー",
    "hǔ": "フー",
    "hù": "フー",
    "hua": "ファ",
    "huā": "ファー",
    "huá": "ファー",
    "huǎ": "ファー",
    "huà": "ファー",
    "huai": "ファイ",
    "huāi": "ファーイ",
    "huái": "ファーイ",
    "huǎi": "ファーイ",
    "huài": "ファーイ",
    "huan": "ファン",
    "huān": "ファーン",
    "huán": "ファーン",
    "huǎn": "ファーン",
    "huàn": "ファーン",
    "huang": "ファン",
    "huāng": "ファーン",
    "huáng": "ファーン",
    "huǎng": "ファーン",
    "huàng": "ファーン",
    "hui": "フェイ",
    "huī": "フェーイ",
    "huí": "フェーイ",
    "huǐ": "フェーイ",
    "huì": "フェーイ",
    "hun": "フン",
    "hūn": "フーン",
    "hún": "フーン",
    "hǔn": "フーン",
    "hùn": "フーン",
    "huo": "フォ",
    "huō": "フォー",
    "huó": "フォー",
    "huǒ": "フォー",
    "huò": "フォー",
    "ji": "ジ",
    "jī": "ジー",
    "jí": "ジー",
    "jǐ": "ジー",
    "jì": "ジー",
    "jia": "ジャ",
    "jiā": "ジャー",
    "jiá": "ジャー",
    "jiǎ": "ジャー",
    "jià": "ジャー",
    "jian": "ジェン",
    "jiān": "ジェーン",
    "jián": "ジェーン",
    "jiǎn": "ジェーン",
    "jiàn": "ジェーン",
    "jiang": "ジャン",
    "jiāng": "ジャーン",
    "jiáng": "ジャーン",
    "jiǎng": "ジャーン",
    "jiàng": "ジャーン",
    "jiao": "ジャオ",
    "jiāo": "ジャーオ",
    "jiáo": "ジャーオ",
    "jiǎo": "ジャーオ",
    "jiào": "ジャーオ",
    "jie": "ジェ",
    "jiē": "ジェー",
    "jié": "ジェー",
    "jiě": "ジェー",
    "jiè": "ジェー",
    "jin": "ジン",
    "jīn": "ジーン",
    "jín": "ジーン",
    "jǐn": "ジーン",
    "jìn": "ジーン",
    "jing": "ジン",
    "jīng": "ジーン",
    "jíng": "ジーン",
    "jǐng": "ジーン",
    "jìng": "ジーン",
    "jiong": "ジョン",
    "jiōng": "ジョーン",
    "jióng": "ジョーン",
    "jiǒng": "ジョーン",
    "jiòng": "ジョーン",
    "jiu": "ジウ",
    "jiū": "ジーウ",
    "jiú": "ジーウ",
    "jiǔ": "ジーウ",
    "jiù": "ジーウ",
    "ju": "ジュ",
    "jū": "ジュー",
    "jú": "ジュー",
    "jǔ": "ジュー",
    "jù": "ジュー",
    "juan": "ジュアン",
    "juān": "ジューアン",
    "juán": "ジューアン",
    "juǎn": "ジューアン",
    "juàn": "ジューアン",
    "jue": "ジュェ",
    "juē": "ジュェー",
    "jué": "ジュェー",
    "juě": "ジュェー",
    "juè": "ジュェー",
    "jun": "ジュン",
    "jūn": "ジューン",
    "jún": "ジューン",
    "jǔn": "ジューン",
    "jùn": "ジューン",
    "ka": "カ",
    "kā": "カー",
    "ká": "カー",
    "kǎ": "カー",
    "kà": "カー",
    "kai": "カイ",
    "kāi": "カーイ",
    "kái": "カーイ",
    "kǎi": "カーイ",
    "kài": "カーイ",
    "kan": "カン",
    "kān": "カーン",
    "kán": "カーン",
    "kǎn": "カーン",
    "kàn": "カーン",
    "kang": "カン",
    "kāng": "カーン",
    "káng": "カーン",
    "kǎng": "カーン",
    "kàng": "カーン",
    "kao": "カオ",
    "kāo": "カーオ",
    "káo": "カーオ",
    "kǎo": "カーオ",
    "kào": "カーオ",
    "ke": "ケ",
    "kē": "ケー",
    "ké": "ケー",
    "kě": "ケー",
    "kè": "ケー",
    "kei": "ケイ",
    "kēi": "ケーイ",
    "kéi": "ケーイ",
    "kěi": "ケーイ",
    "kèi": "ケーイ",
    "ken": "ケン",
    "kēn": "ケーン",
    "kén": "ケーン",
    "kěn": "ケーン",
    "kèn": "ケーン",
    "keng": "ケン",
    "kēng": "ケーン",
    "kéng": "ケーン",
    "kěng": "ケーン",
    "kèng": "ケーン",
    "kong": "コン",
    "kōng": "コーン",
    "kóng": "コーン",
    "kǒng": "コーン",
    "kòng": "コーン",
    "kou": "コウ",
    "kōu": "コーウ",
    "kóu": "コーウ",
    "kǒu": "コーウ",
    "kòu": "コーウ",
    "ku": "ク",
    "kū": "クー",
    "kú": "クー",
    "kǔ": "クー",
    "kù": "クー",
    "kua": "クア",
    "kuā": "クーア",
    "kuá": "クーア",
    "kuǎ": "クーア",
    "kuà": "クーア",
    "kuai": "クアイ",
    "kuāi": "クーアイ",
    "kuái": "クーアイ",
    "kuǎi": "クーアイ",
    "kuài": "クーアイ",
    "kuan": "クァン",
    "kuān": "クーァン",
    "kuán": "クーァン",
    "kuǎn": "クーァン",
    "kuàn": "クーァン",
    "kuang": "クァン",
    "kuāng": "クーァン",
    "kuáng": "クーァン",
    "kuǎng": "クーァン",
    "kuàng": "クーァン",
    "kui": "クェイ",
    "kuī": "クェーイ",
    "kuí": "クェーイ",
    "kuǐ": "クェーイ",
    "kuì": "クェーイ",
    "kun": "クン",
    "kūn": "クーン",
    "kún": "クーン",
    "kǔn": "クーン",
    "kùn": "クーン",
    "kuo": "クォ",
    "kuō": "クーォ",
    "kuó": "クーォ",
    "kuǒ": "クーォ",
    "kuò": "クーォ",
    "la": "ラ",
    "lā": "ラー",
    "lá": "ラー",
    "lǎ": "ラー",
    "là": "ラー",
    "lái": "ライ",
    "lai": "ライ",
    "lāi": "ライ",
    "laí": "ライ",
    "lǎi": "ライ",
    "lài": "ライ",
    "lan": "ラン",
    "lān": "ラーン",
    "lán": "ラーン",
    "lǎn": "ラーン",
    "làn": "ラーン",
    "lang": "ラン",
    "lāng": "ラーン",
    "láng": "ラーン",
    "lǎng": "ラーン",
    "làng": "ラーン",
    "lao": "ラオ",
    "lāo": "ラーオ",
    "laó": "ラーオ",
    "lǎo": "ラーオ",
    "lào": "ラーオ",
    "le": "レ",
    "lē": "レー",
    "lé": "レー",
    "lě": "レー",
    "lè": "レー",
    "lei": "レイ",
    "lēi": "レーイ",
    "léi": "レーイ",
    "lěi": "レーイ",
    "lèi": "レーイ",
    "leng": "レン",
    "lēng": "レーン",
    "léng": "レーン",
    "lěng": "レーン",
    "lèng": "レーン",
    "li": "リ",
    "lī": "リー",
    "lí": "リー",
    "lǐ": "リー",
    "lì": "リー",
    "lia": "リャ",
    "liā": "リーア",
    "liá": "リーア",
    "liǎ": "リーア",
    "lià": "リーア",
    "lian": "リェン",
    "liān": "リーエン",
    "lián": "リーエン",
    "liǎn": "リーエン",
    "liàn": "リーエン",
    "liang": "リャン",
    "liāng": "リーァン",
    "liáng": "リーァン",
    "liǎng": "リーァン",
    "liàng": "リーァン",
    "liao": "リャオ",
    "liāo": "リーアオ",
    "liáo": "リーアオ",
    "liǎo": "リーアオ",
    "liào": "リーアオ",
    "lie": "リェ",
    "liē": "リーエ",
    "lié": "リーエ",
    "liě": "リーエ",
    "liè": "リーエ",
    "lin": "リン",
    "līn": "リーン",
    "lín": "リーン",
    "lǐn": "リーン",
    "lìn": "リーン",
    "ling": "リン",
    "līng": "リーン",
    "líng": "リーン",
    "lǐng": "リーン",
    "lìng": "リーン",
    "liu": "リウ",
    "līu": "リーウ",
    "liú": "リーウ",
    "liǔ": "リーウ",
    "liù": "リーウ",
    "long": "ロン",
    "lóng": "ローン",
    "lǒng": "ローン",
    "lòng": "ローン",
    "lou": "ロウ",
    "lōu": "ローウ",
    "lóu": "ローウ",
    "lǒu": "ローウ",
    "lòu": "ローウ",
    "lu": "ル",
    "lū": "ルー",
    "lú": "ルー",
    "lǔ": "ルー",
    "lù": "ルー",
    "luan": "ルァン",
    "luān": "ルーアン",
    "luán": "ルーアン",
    "luǎn": "ルーアン",
    "luàn": "ルーアン",
    "lue": "ルェ",
    "luē": "ルーエ",
    "lué": "ルーエ",
    "luě": "ルーエ",
    "luè": "ルーエ",
    "lun": "ルン",
    "lūn": "ルーン",
    "lún": "ルーン",
    "lǔn": "ルーン",
    "lùn": "ルーン",
    "luo": "ルォ",
    "luō": "ルーォ",
    "luó": "ルーォ",
    "luǒ": "ルーォ",
    "luò": "ルーォ",
    "ma": "マ",
    "mā": "マー",
    "má": "マー",
    "mǎ": "マー",
    "mà": "マー",
    "mai": "マイ",
    "māi": "マーイ",
    "maí": "マーイ",
    "mǎi": "マーイ",
    "mài": "マーイ",
    "man": "マン",
    "mān": "マーン",
    "mán": "マーン",
    "mǎn": "マーン",
    "màn": "マーン",
    "mang": "マン",
    "māng": "マーン",
    "máng": "マーン",
    "mǎng": "マーン",
    "màng": "マーン",
    "mao": "マオ",
    "māo": "マーオ",
    "maó": "マーオ",
    "mǎo": "マーオ",
    "mào": "マーオ",
    "me": "メ",
    "mē": "メー",
    "mé": "メー",
    "mě": "メー",
    "mè": "メー",
    "mei": "メイ",
    "mēi": "メーイ",
    "méi": "メーイ",
    "měi": "メーイ",
    "mèi": "メーイ",
    "men": "メン",
    "mēn": "メーン",
    "mén": "メーン",
    "měn": "メーン",
    "mèn": "メーン",
    "meng": "メン",
    "mēng": "メーン",
    "méng": "メーン",
    "měng": "メーン",
    "mèng": "メーン",
    "mi": "ミ",
    "mī": "ミー",
    "mí": "ミー",
    "mǐ": "ミー",
    "mì": "ミー",
    "mian": "ミェン",
    "miān": "ミーエン",
    "mián": "ミーエン",
    "miǎn": "ミーエン",
    "miàn": "ミーエン",
    "miao": "ミャオ",
    "miāo": "ミーアオ",
    "miáo": "ミーアオ",
    "miǎo": "ミーアオ",
    "miào": "ミーアオ",
    "mie": "ミェ",
    "miē": "ミーエ",
    "mié": "ミーエ",
    "miě": "ミーエ",
    "miè": "ミーエ",
    "min": "ミン",
    "mīn": "ミーン",
    "mín": "ミーン",
    "mǐn": "ミーン",
    "mìn": "ミーン",
    "ming": "ミン",
    "mīng": "ミーン",
    "míng": "ミーン",
    "mǐng": "ミーン",
    "mìng": "ミーン",
    "miu": "ミウ",
    "mīu": "ミーウ",
    "miú": "ミーウ",
    "miǔ": "ミーウ",
    "miù": "ミーウ",
    "mo": "モ",
    "mō": "モー",
    "mó": "モー",
    "mǒ": "モー",
    "mò": "モー",
    "mou": "モウ",
    "mōu": "モーウ",
    "moú": "モーウ",
    "mǒu": "モーウ",
    "moù": "モーウ",
    "mu": "ム",
    "mū": "ムー",
    "mú": "ムー",
    "mǔ": "ムー",
    "mù": "ムー",
    "na": "ナ",
    "nā": "ナー",
    "ná": "ナー",
    "nǎ": "ナー",
    "nà": "ナー",
    "nai": "ナイ",
    "nāi": "ナーイ",
    "naí": "ナーイ",
    "nǎi": "ナーイ",
    "nài": "ナーイ",
    "nan": "ナン",
    "nān": "ナーン",
    "nán": "ナーン",
    "nǎn": "ナーン",
    "nàn": "ナーン",
    "nang": "ナン",
    "nāng": "ナーン",
    "náng": "ナーン",
    "nǎng": "ナーン",
    "nàng": "ナーン",
    "nao": "ナオ",
    "nāo": "ナーオ",
    "naó": "ナーオ",
    "nǎo": "ナーオ",
    "nào": "ナーオ",
    "ne": "ネ",
    "nē": "ネー",
    "né": "ネー",
    "ně": "ネー",
    "nè": "ネー",
    "nei": "ネイ",
    "nēi": "ネーイ",
    "néi": "ネーイ",
    "něi": "ネーイ",
    "nèi": "ネーイ",
    "nen": "ネン",
    "nēn": "ネーン",
    "nén": "ネーン",
    "něn": "ネーン",
    "nèn": "ネーン",
    "neng": "ネン",
    "nēng": "ネーン",
    "néng": "ネーン",
    "něng": "ネーン",
    "nèng": "ネーン",
    "ni": "ニ",
    "nī": "ニー",
    "ní": "ニー",
    "nǐ": "ニー",
    "nì": "ニー",
    "nian": "ニェン",
    "niān": "ニャーン",
    "nián": "ニャーン",
    "niǎn": "ニャーン",
    "niàn": "ニャーン",
    "niang": "ニャン",
    "niāng": "ニャーン",
    "niáng": "ニャーン",
    "niǎng": "ニャーン",
    "niàng": "ニャーン",
    "niao": "ニャオ",
    "niāo": "ニャオー",
    "niáo": "ニャオー",
    "niǎo": "ニャオー",
    "niào": "ニャオー",
    "nie": "ニェ",
    "nīe": "ニェー",
    "níe": "ニェー",
    "nǐe": "ニェー",
    "nìe": "ニェー",
    "nin": "ニン",
    "nīn": "ニーン",
    "nín": "ニーン",
    "nǐn": "ニーン",
    "nìn": "ニーン",
    "ning": "ニン",
    "nīng": "ニーン",
    "níng": "ニーン",
    "nǐng": "ニーン",
    "nìng": "ニーン",
    "niu": "ニウ",
    "nīu": "ニーウ",
    "níu": "ニーウ",
    "nǐu": "ニーウ",
    "nòu": "ニーウ",
    "nong": "ノン",
    "nōng": "ノーン",
    "nóng": "ノーン",
    "nǒng": "ノーン",
    "nòng": "ノーン",
    "nou": "ノウ",
    "nōu": "ノーウ",
    "nóu": "ノーウ",
    "nǒu": "ノーウ",
    "nòu": "ノーウ",
    "nu": "ヌ",
    "nū": "ヌー",
    "nú": "ヌー",
    "nǔ": "ヌー",
    "nù": "ヌー",
    "nǚ": "ニュ",
    "nǚe": "ニュエ",
    "nǚan": "ニュアン",
    "nǚang": "ニュアン",
    "nǚei": "ニュエイ",
    "nǚen": "ニュエン",
    "nuan": "ヌァン",
    "nuān": "ヌァーン",
    "nuán": "ヌァーン",
    "nuǎn": "ヌァーン",
    "nuàn": "ヌァーン",
    "nue": "ヌェ",
    "nuē": "ヌェー",
    "nué": "ヌェー",
    "nuě": "ヌェー",
    "nuè": "ヌェー",
    "nun": "ヌン",
    "nūn": "ヌーン",
    "nún": "ヌーン",
    "nǔn": "ヌーン",
    "nùn": "ヌーン",
    "nuo": "ヌォ",
    "nuō": "ヌォー",
    "nuó": "ヌォー",
    "nuǒ": "ヌォー",
    "nuò": "ヌォー",
    "o": "オ",
    "ō": "オー",
    "ó": "オー",
    "ǒ": "オー",
    "ò": "オー",
    "ou": "オウ",
    "ōu": "オーウ",
    "óu": "オーウ",
    "ǒu": "オーウ",
    "òu": "オーウ",
    "pa": "パ",
    "pā": "パー",
    "pá": "パー",
    "pǎ": "パー",
    "pà": "パー",
    "pai": "パイ",
    "pāi": "パーイ",
    "pái": "パーイ",
    "pǎi": "パーイ",
    "pài": "パーイ",
    "pan": "パン",
    "pān": "パーン",
    "pán": "パーン",
    "pǎn": "パーン",
    "pàn": "パーン",
    "pang": "パン",
    "pāng": "パーン",
    "páng": "パーン",
    "pǎng": "パーン",
    "pàng": "パーン",
    "pao": "パオ",
    "pāo": "パーオ",
    "páo": "パーオ",
    "pǎo": "パーオ",
    "pào": "パーオ",
    "pe": "ペ",
    "pē": "ペー",
    "pé": "ペー",
    "pě": "ペー",
    "pè": "ペー",
    "pei": "ペイ",
    "pēi": "ペーイ",
    "péi": "ペーイ",
    "pěi": "ペーイ",
    "pèi": "ペーイ",
    "pen": "ペン",
    "pēn": "ペーン",
    "pén": "ペーン",
    "pěn": "ペーン",
    "pèn": "ペーン",
    "peng": "ペン",
    "pēng": "ペーン",
    "péng": "ペーン",
    "pěng": "ペーン",
    "pèng": "ペーン",
    "pi": "ピ",
    "pī": "ピー",
    "pí": "ピー",
    "pǐ": "ピー",
    "pì": "ピー",
    "pian": "ピェン",
    "piān": "ピェーン",
    "pián": "ピェーン",
    "piǎn": "ピェーン",
    "piàn": "ピェーン",
    "piao": "ピャオ",
    "piāo": "ピャーオ",
    "piáo": "ピャーオ",
    "piǎo": "ピャーオ",
    "piào": "ピャーオ",
    "pie": "ピェ",
    "piē": "ピェー",
    "pié": "ピェー",
    "piě": "ピェー",
    "piè": "ピェー",
    "pin": "ピン",
    "pīn": "ピーン",
    "pín": "ピーン",
    "pǐn": "ピーン",
    "pìn": "ピーン",
    "ping": "ピン",
    "pīng": "ピーン",
    "píng": "ピーン",
    "pǐng": "ピーン",
    "pìng": "ピーン",
    "po": "ポ",
    "pō": "ポー",
    "pó": "ポー",
    "pǒ": "ポー",
    "pò": "ポー",
    "pou": "ポウ",
    "pōu": "ポーウ",
    "póu": "ポーウ",
    "pǒu": "ポーウ",
    "pòu": "ポーウ",
    "pu": "プ",
    "pū": "プー",
    "pú": "プー",
    "pǔ": "プー",
    "pù": "プー",
    "qi": "チ",
    "qī": "チー",
    "qí": "チー",
    "qǐ": "チー",
    "qì": "チー",
    "qia": "チャ",
    "qiā": "チャー",
    "qiá": "チャー",
    "qiǎ": "チャー",
    "qià": "チャー",
    "qian": "チェン",
    "qiān": "チェーン",
    "qián": "チェーン",
    "qiǎn": "チェーン",
    "qiàn": "チェーン",
    "qiang": "チャン",
    "qiāng": "チャーン",
    "qiáng": "チャーン",
    "qiǎng": "チャーン",
    "qiàng": "チャーン",
    "qiao": "チャオ",
    "qiāo": "チャーオ",
    "qiáo": "チャーオ",
    "qiǎo": "チャーオ",
    "qiào": "チャーオ",
    "qie": "チェ",
    "qiē": "チェー",
    "qié": "チェー",
    "qiě": "チェー",
    "qiè": "チェー",
    "qin": "チン",
    "qīn": "チーン",
    "qín": "チーン",
    "qǐn": "チーン",
    "qìn": "チーン",
    "qing": "チン",
    "qīng": "チーン",
    "qíng": "チーン",
    "qǐng": "チーン",
    "qìng": "チーン",
    "qiong": "チョン",
    "qiōng": "チョーン",
    "qióng": "チョーン",
    "qiǒng": "チョーン",
    "qiòng": "チョーン",
    "qiu": "チウ",
    "qiū": "チーウ",
    "qiú": "チーウ",
    "qiǔ": "チーウ",
    "qiù": "チーウ",
    "qu": "チュ",
    "qū": "チュー",
    "qú": "チュー",
    "qǔ": "チュー",
    "qù": "チュー",
    "quan": "チュアン",
    "quān": "チューアン",
    "quán": "チューアン",
    "quǎn": "チューアン",
    "quàn": "チューアン",
    "que": "チュェ",
    "quē": "チュェー",
    "qué": "チュェー",
    "quě": "チュェー",
    "què": "チュェー",
    "qun": "チュン",
    "qūn": "チューン",
    "qún": "チューン",
    "qǔn": "チューン",
    "qùn": "チューン",
    "ran": "ラン",
    "rān": "ラーン",
    "rán": "ラーン",
    "rǎn": "ラーン",
    "ràn": "ラーン",
    "rang": "ラン",
    "rāng": "ラーン",
    "ráng": "ラーン",
    "rǎng": "ラーン",
    "ràng": "ラーン",
    "rao": "ラオ",
    "rāo": "ラーオ",
    "ráo": "ラーオ",
    "rǎo": "ラーオ",
    "rào": "ラーオ",
    "re": "レ",
    "rē": "レー",
    "ré": "レー",
    "rě": "レー",
    "rè": "レー",
    "ren": "レン",
    "rēn": "レーン",
    "rěn": "レーン",
    "rèn": "レーン",
    "reng": "レン",
    "rēng": "レーン",
    "rěng": "レーン",
    "rèng": "レーン",
    "ri": "リ",
    "rī": "リー",
    "rí": "リー",
    "rǐ": "リー",
    "rì": "リー",
    "rong": "ロン",
    "róng": "ローン",
    "rǒng": "ローン",
    "ròng": "ローン",
    "rou": "ロウ",
    "rōu": "ロー",
    "róu": "ロー",
    "rǒu": "ロー",
    "ròu": "ロー",
    "ru": "ル",
    "rū": "ルー",
    "rú": "ルー",
    "rǔ": "ルー",
    "rù": "ルー",
    "ruan": "ルァン",
    "ruān": "ルァーン",
    "ruán": "ルァーン",
    "ruǎn": "ルァーン",
    "ruàn": "ルァーン",
    "rui": "ルェイ",
    "ruī": "ルェーイ",
    "ruí": "ルェーイ",
    "ruǐ": "ルェーイ",
    "ruì": "ルェーイ",
    "run": "ルン",
    "rūn": "ルーン",
    "rún": "ルーン",
    "rǔn": "ルーン",
    "rùn": "ルーン",
    "ruo": "ルォ",
    "ruō": "ルォー",
    "ruó": "ルォー",
    "ruǒ": "ルォー",
    "ruò": "ルォー",
    "sa": "サ",
    "sā": "サー",
    "sá": "サー",
    "sǎ": "サー",
    "sà": "サー",
    "sai": "サイ",
    "sāi": "サーイ",
    "sái": "サーイ",
    "sǎi": "サーイ",
    "sài": "サーイ",
    "san": "サン",
    "sān": "サーン",
    "sán": "サーン",
    "sǎn": "サーン",
    "sàn": "サーン",
    "sang": "サン",
    "sāng": "サーン",
    "sáng": "サーン",
    "sǎng": "サーン",
    "sàng": "サーン",
    "sao": "サオ",
    "sāo": "サーオ",
    "sáo": "サーオ",
    "sǎo": "サーオ",
    "sào": "サーオ",
    "se": "セ",
    "sē": "セー",
    "sé": "セー",
    "sě": "セー",
    "sè": "セー",
    "sei": "セイ",
    "sēi": "セーイ",
    "séi": "セーイ",
    "sěi": "セーイ",
    "sèi": "セーイ",
    "sen": "セン",
    "sēn": "セーン",
    "sén": "セーン",
    "sěn": "セーン",
    "sèn": "セーン",
    "seng": "セン",
    "sēng": "セーン",
    "séng": "セーン",
    "sěng": "セーン",
    "sèng": "セーン",
    "sha": "シャ",
    "shā": "シャー",
    "shá": "シャー",
    "shǎ": "シャー",
    "shà": "シャー",
    "shai": "シャイ",
    "shāi": "シャーイ",
    "shái": "シャーイ",
    "shǎi": "シャーイ",
    "shài": "シャーイ",
    "shan": "シャン",
    "shān": "シャーン",
    "shán": "シャーン",
    "shǎn": "シャーン",
    "shàn": "シャーン",
    "shang": "シャン",
    "shāng": "シャーン",
    "sháng": "シャーン",
    "shǎng": "シャーン",
    "shàng": "シャーン",
    "shao": "シャオ",
    "shāo": "シャーオ",
    "sháo": "シャーオ",
    "shǎo": "シャーオ",
    "shào": "シャーオ",
    "she": "シェ",
    "shē": "シェー",
    "shé": "シェー",
    "shě": "シェー",
    "shè": "シェー",
    "shei": "シェイ",
    "shēi": "シェーイ",
    "shéi": "シェーイ",
    "shěi": "シェーイ",
    "shèi": "シェーイ",
    "shen": "シェン",
    "shēn": "シェーン",
    "shén": "シェーン",
    "shěn": "シェーン",
    "shèn": "シェーン",
    "sheng": "シェン",
    "shēng": "シェーン",
    "shéng": "シェーン",
    "shěng": "シェーン",
    "shèng": "シェーン",
    "shi": "シ",
    "shī": "シー",
    "shí": "シー",
    "shǐ": "シー",
    "shì": "シー",
    "shou": "ショウ",
    "shōu": "ショー",
    "shóu": "ショー",
    "shǒu": "ショー",
    "shòu": "ショー",
    "shu": "シュ",
    "shū": "シュー",
    "shú": "シュー",
    "shǔ": "シュー",
    "shù": "シュー",
    "shua": "シュア",
    "shuā": "シューア",
    "shuá": "シューア",
    "shuǎ": "シューア",
    "shuài": "シュアイ",
    "shuāi": "シューアイ",
    "shuái": "シューアイ",
    "shuǎi": "シューアイ",
    "shuàn": "シュアン",
    "shuān": "シューアン",
    "shuán": "シューアン",
    "shuǎn": "シューアン",
    "shuàng": "シュァン",
    "shuāng": "シューァン",
    "shuáng": "シューァン",
    "shuǎng": "シューァン",
    "shui": "シュェイ",
    "shuī": "シュェーイ",
    "shuí": "シュェーイ",
    "shuǐ": "シュェーイ",
    "shuì": "シュェーイ",
    "shun": "シュン",
    "shūn": "シューン",
    "shún": "シューン",
    "shǔn": "シューン",
    "shùn": "シューン",
    "shuo": "シュォ",
    "shuō": "シュォー",
    "shuó": "シュォー",
    "shuǒ": "シュォー",
    "shuò": "シュォー",
    "si": "ス",
    "sī": "スー",
    "sí": "スー",
    "sǐ": "スー",
    "sì": "スー",
    "song": "ソン",
    "sōng": "ソーン",
    "sóng": "ソーン",
    "sǒng": "ソーン",
    "sòng": "ソーン",
    "sou": "ソウ",
    "sōu": "ソー",
    "sóu": "ソー",
    "sǒu": "ソー",
    "sòu": "ソー",
    "su": "ス",
    "sū": "スー",
    "sú": "スー",
    "sǔ": "スー",
    "sù": "スー",
    "suan": "スァン",
    "suān": "スーァン",
    "suán": "スーァン",
    "suǎn": "スーァン",
    "suàn": "スーァン",
    "sui": "スェイ",
    "suī": "スェーイ",
    "suí": "スェーイ",
    "suǐ": "スェーイ",
    "suì": "スェーイ",
    "sun": "スン",
    "sūn": "スーン",
    "sún": "スーン",
    "sǔn": "スーン",
    "sùn": "スーン",
    "suo": "スォ",
    "suō": "スォー",
    "suó": "スォー",
    "suǒ": "スォー",
    "suò": "スォー",
    "ta": "タ",
    "tā": "ター",
    "tá": "ター",
    "tǎ": "ター",
    "tà": "ター",
    "tai": "タイ",
    "tāi": "ターイ",
    "tái": "ターイ",
    "tǎi": "ターイ",
    "tài": "ターイ",
    "tan": "タン",
    "tān": "ターン",
    "tán": "ターン",
    "tǎn": "ターン",
    "tàn": "ターン",
    "tang": "タン",
    "tāng": "ターン",
    "táng": "ターン",
    "tǎng": "ターン",
    "tàng": "ターン",
    "tao": "タオ",
    "tāo": "ターオ",
    "táo": "ターオ",
    "tǎo": "ターオ",
    "tào": "ターオ",
    "te": "テ",
    "tē": "テー",
    "té": "テー",
    "tě": "テー",
    "tè": "テー",
    "tei": "テイ",
    "tēi": "テーイ",
    "téi": "テーイ",
    "těi": "テーイ",
    "tèi": "テーイ",
    "ten": "テン",
    "tēn": "テーン",
    "tén": "テーン",
    "těn": "テーン",
    "tèn": "テーン",
    "tang": "タン",
    "tāng": "ターン",
    "táng": "ターン",
    "tǎng": "ターン",
    "tàng": "ターン",
    "tiān": "ティエン",
    "tiān": "ティエン",
    "tián": "ティエン",
    "tiǎn": "ティエン",
    "tiàn": "ティエン",
    "tong": "トン",
    "tōng": "トーン",
    "tóng": "トーン",
    "tǒng": "トーン",
    "tòng": "トーン",
    "tou": "トウ",
    "tōu": "トーウ",
    "tóu": "トーウ",
    "tǒu": "トーウ",
    "tòu": "トーウ",
    "te": "テ",
    "tē": "テー",
    "té": "テー",
    "tě": "テー",
    "tè": "テー",
    "tei": "テイ",
    "tēi": "テーイ",
    "téi": "テーイ",
    "těi": "テーイ",
    "tèi": "テーイ",
    "ten": "テン",
    "tēn": "テーン",
    "tén": "テーン",
    "těn": "テーン",
    "tèn": "テーン",
    "tong": "トン",
    "tōng": "トーン",
    "tóng": "トーン",
    "tǒng": "トーン",
    "tòng": "トーン",
    "tou": "トウ",
    "tōu": "トーウ",
    "tóu": "トーウ",
    "tǒu": "トーウ",
    "tòu": "トーウ",
    "tu": "ツ",
    "tū": "ツー",
    "tú": "ツー",
    "tǔ": "ツー",
    "tù": "ツー",
    "tuan": "ツァン",
    "tuān": "ツァーン",
    "tuán": "ツァーン",
    "tuǎn": "ツァーン",
    "tuàn": "ツァーン",
    "tui": "ツェイ",
    "tuī": "ツェーイ",
    "tuí": "ツェーイ",
    "tuǐ": "ツェーイ",
    "tuì": "ツェーイ",
    "tun": "ツン",
    "tūn": "ツーン",
    "tún": "ツーン",
    "tǔn": "ツーン",
    "tùn": "ツーン",
    "tuo": "ツォ",
    "tuō": "ツォー",
    "tuó": "ツォー",
    "tuǒ": "ツォー",
    "tuò": "ツォー",
    "wa": "ワ",
    "wā": "ワー",
    "wá": "ワー",
    "wǎ": "ワー",
    "wà": "ワー",
    "wai": "ワイ",
    "wāi": "ワーイ",
    "wái": "ワーイ",
    "wǎi": "ワーイ",
    "wài": "ワーイ",
    "wan": "ワン",
    "wān": "ワーン",
    "wán": "ワーン",
    "wǎn": "ワーン",
    "wàn": "ワーン",
    "wang": "ワン",
    "wāng": "ワーン",
    "wáng": "ワーン",
    "wǎng": "ワーン",
    "wàng": "ワーン",
    "wei": "ウェイ",
    "wēi": "ウェーイ",
    "wéi": "ウェーイ",
    "wěi": "ウェーイ",
    "wèi": "ウェーイ",
    "wen": "ウェン",
    "wēn": "ウェーン",
    "wén": "ウェーン",
    "wěn": "ウェーン",
    "wèn": "ウェーン",
    "weng": "ウォン",
    "wēng": "ウォーン",
    "wéng": "ウォーン",
    "wěng": "ウォーン",
    "wèng": "ウォーン",
    "wo": "ウォ",
    "wō": "ウォー",
    "wó": "ウォー",
    "wǒ": "ウォー",
    "wò": "ウォー",
    "wu": "ウ",
    "wū": "ウー",
    "wú": "ウー",
    "wǔ": "ウー",
    "wù": "ウー",
    "xi": "シ",
    "xī": "シー",
    "xí": "シー",
    "xǐ": "シー",
    "xì": "シー",
    "xia": "シャ",
    "xiā": "シャー",
    "xiá": "シャー",
    "xiǎ": "シャー",
    "xià": "シャー",
    "xian": "シェン",
    "xiān": "シェーン",
    "xián": "シェーン",
    "xiǎn": "シェーン",
    "xiàn": "シェーン",
    "xiang": "シャン",
    "xiāng": "シャーン",
    "xiáng": "シャーン",
    "xiǎng": "シャーン",
    "xiàng": "シャーン",
    "xiao": "シャオ",
    "xiāo": "シャーオ",
    "xiáo": "シャーオ",
    "xiǎo": "シャーオ",
    "xiào": "シャーオ",
    "xie": "シェ",
    "xiē": "シェー",
    "xié": "シェー",
    "xiě": "シェー",
    "xiè": "シェー",
    "xin": "シン",
    "xīn": "シーン",
    "xín": "シーン",
    "xǐn": "シーン",
    "xìn": "シーン",
    "xing": "シン",
    "xīng": "シーン",
    "xíng": "シーン",
    "xǐng": "シーン",
    "xìng": "シーン",
    "xiong": "ション",
    "xiōng": "ショーン",
    "xióng": "ショーン",
    "xiǒng": "ショーン",
    "xiòng": "ショーン",
    "xiu": "シュウ",
    "xiū": "シュー",
    "xiú": "シュー",
    "xiǔ": "シュー",
    "xiù": "シュー",
    "xu": "シュ",
    "xū": "シュー",
    "xú": "シュー",
    "xǔ": "シュー",
    "xù": "シュー",
    "xuan": "シュアン",
    "xuān": "シューアン",
    "xuán": "シューアン",
    "xuǎn": "シューアン",
    "xuàn": "シューアン",
    "xue": "シュエ",
    "xuē": "シューエ",
    "xué": "シューエ",
    "xuě": "シューエ",
    "xuè": "シューエ",
    "xun": "シュン",
    "xūn": "シューン",
    "xún": "シューン",
    "xǔn": "シューン",
    "xùn": "シューン",
    "ya": "ヤ",
    "yā": "ヤー",
    "yá": "ヤー",
    "yǎ": "ヤー",
    "yà": "ヤー",
    "yan": "ヤン",
    "yān": "ヤーン",
    "yán": "ヤーン",
    "yǎn": "ヤーン",
    "yàn": "ヤーン",
    "yang": "ヤン",
    "yāng": "ヤーン",
    "yáng": "ヤーン",
    "yǎng": "ヤーン",
    "yàng": "ヤーン",
    "yao": "ヤオ",
    "yāo": "ヤーオ",
    "yáo": "ヤーオ",
    "yǎo": "ヤーオ",
    "yào": "ヤーオ",
    "ye": "イェ",
    "yē": "イェー",
    "yé": "イェー",
    "yě": "イェー",
    "yè": "イェー",
    "yi": "イ",
    "yī": "イー",
    "yí": "イー",
    "yǐ": "イー",
    "yì": "イー",
    "yin": "イン",
    "yīn": "イン",
    "yín": "イン",
    "yǐn": "イン",
    "yìn": "イン",
    "ying": "イン",
    "yīng": "イン",
    "yíng": "イン",
    "yǐng": "イン",
    "yìng": "イン",
    "yo": "ヨ",
    "yō": "ヨー",
    "yó": "ヨー",
    "yǒ": "ヨー",
    "yò": "ヨー",
    "yong": "ヨン",
    "yōng": "ヨーン",
    "yóng": "ヨーン",
    "yǒng": "ヨーン",
    "yòng": "ヨーン",
    "you": "ヨウ",
    "yōu": "ヨーウ",
    "yóu": "ヨーウ",
    "yǒu": "ヨーウ",
    "yòu": "ヨーウ",
    "yū": "ユー",
    "yú": "ユー",
    "yǔ": "ユー",
    "yù": "ユー",
    "yuan": "ユアン",
    "yuān": "ユーアン",
    "yuán": "ユーアン",
    "yuǎn": "ユーアン",
    "yuàn": "ユーアン",
    "yue": "ユエ",
    "yuē": "ユーエ",
    "yué": "ユーエ",
    "yuě": "ユーエ",
    "yuè": "ユーエ",
    "yun": "ユン",
    "yūn": "ユーン",
    "yún": "ユーン",
    "yǔn": "ユーン",
    "yùn": "ユーン",
    "za": "ザ",
    "zā": "ザー",
    "zá": "ザー",
    "zǎ": "ザー",
    "zà": "ザー",
    "zai": "ザイ",
    "zāi": "ザーイ",
    "zái": "ザーイ",
    "zǎi": "ザーイ",
    "zài": "ザーイ",
    "zan": "ザン",
    "zān": "ザーン",
    "zán": "ザーン",
    "zǎn": "ザーン",
    "zàn": "ザーン",
    "zang": "ザン",
    "zāng": "ザーン",
    "záng": "ザーン",
    "zǎng": "ザーン",
    "zàng": "ザーン",
    "zao": "ザオ",
    "zāo": "ザーオ",
    "záo": "ザーオ",
    "zǎo": "ザーオ",
    "zào": "ザーオ",
    "ze": "ゼ",
    "zē": "ゼー",
    "zé": "ゼー",
    "zě": "ゼー",
    "zè": "ゼー",
    "zei": "ゼイ",
    "zēi": "ゼーイ",
    "zéi": "ゼーイ",
    "zěi": "ゼーイ",
    "zèi": "ゼーイ",
    "zen": "ゼン",
    "zēn": "ゼーン",
    "zén": "ゼーン",
    "zěn": "ゼーン",
    "zèn": "ゼーン",
    "zeng": "ゾン",
    "zēng": "ゾーン",
    "zéng": "ゾーン",
    "zěng": "ゾーン",
    "zèng": "ゾーン",
    "zha": "ジャ",
    "zhā": "ジャー",
    "zhá": "ジャー",
    "zhǎ": "ジャー",
    "zhà": "ジャー",
    "zhai": "ジャイ",
    "zhāi": "ジャーイ",
    "zhái": "ジャーイ",
    "zhǎi": "ジャーイ",
    "zhài": "ジャーイ",
    "zhan": "ジャン",
    "zhān": "ジャーン",
    "zhán": "ジャーン",
    "zhǎn": "ジャーン",
    "zhàn": "ジャーン",
    "zhang": "ジャン",
    "zhāng": "ジャーン",
    "zháng": "ジャーン",
    "zhǎng": "ジャーン",
    "zhàng": "ジャーン",
    "zhao": "ジャオ",
    "zhāo": "ジャーオ",
    "zháo": "ジャーオ",
    "zhǎo": "ジャーオ",
    "zhào": "ジャーオ",
    "zhe": "ジェ",
    "zhē": "ジェー",
    "zhé": "ジェー",
    "zhě": "ジェー",
    "zhè": "ジェー",
    "zhei": "ジェイ",
    "zhēi": "ジェーイ",
    "zhéi": "ジェーイ",
    "zhěi": "ジェーイ",
    "zhèi": "ジェーイ",
    "zhen": "ジェン",
    "zhēn": "ジェーン",
    "zhén": "ジェーン",
    "zhěn": "ジェーン",
    "zhèn": "ジェーン",
    "zheng": "ジョン",
    "zhēng": "ジョーン",
    "zhéng": "ジョーン",
    "zhěng": "ジョーン",
    "zhèng": "ジョーン",
    "zhi": "ジ",
    "zhī": "ジー",
    "zhí": "ジー",
    "zhǐ": "ジー",
    "zhì": "ジー",
    "zhong": "ジョン",
    "zhōng": "ジョーン",
    "zhóng": "ジョーン",
    "zhǒng": "ジョーン",
    "zhòng": "ジョーン",
    "zhou": "ジョウ",
    "zhōu": "ジョーウ",
    "zhóu": "ジョーウ",
    "zhǒu": "ジョーウ",
    "zhòu": "ジョーウ",
    "zhu": "ジュ",
    "zhū": "ジュー",
    "zhú": "ジュー",
    "zhǔ": "ジュー",
    "zhù": "ジュー",
    "zhua": "ジュア",
    "zhuā": "ジューア",
    "zhuá": "ジューア",
    "zhǔa": "ジューア",
    "zhuà": "ジューア",
    "zhuai": "ジュアイ",
    "zhuāi": "ジューアイ",
    "zhuái": "ジューアイ",
    "zhǔai": "ジューアイ",
    "zhuài": "ジューアイ",
    "zhuan": "ジュアン",
    "zhuān": "ジューアン",
    "zhuán": "ジューアン",
    "zhǔan": "ジューアン",
    "zhuàn": "ジューアン",
    "zhuang": "ジュアン",
    "zhuāng": "ジューアン",
    "zhuáng": "ジューアン",
    "zhǔang": "ジューアン",
    "zhuàng": "ジューアン",
    "zhui": "ジュエイ",
    "zhuī": "ジューエイ",
    "zhuí": "ジューエイ",
    "zhuǐ": "ジューエイ",
    "zhuì": "ジューエイ",
    "zhun": "ジュン",
    "zhūn": "ジューン",
    "zhún": "ジューン",
    "zhǔn": "ジューン",
    "zhùn": "ジューン",
    "zhuo": "ジュオ",
    "zhuō": "ジューオ",
    "zhuó": "ジューオ",
    "zhuǒ": "ジューオ",
}
